package com.bonus.material.plan.mapper;

import java.util.List;
import com.bonus.material.plan.domain.PlanBorrowDetails;

/**
 * 年度借调计划详细Mapper接口
 * 
 * @author xsheng
 * @date 2024-10-16
 */
public interface PlanBorrowDetailsMapper {
    /**
     * 查询年度借调计划详细
     * 
     * @param planId 年度借调计划详细主键
     * @return 年度借调计划详细
     */
    public PlanBorrowDetails selectPlanBorrowDetailsByPlanId(Long planId);

    /**
     * 查询年度借调计划详细列表
     * 
     * @param planBorrowDetails 年度借调计划详细
     * @return 年度借调计划详细集合
     */
    public List<PlanBorrowDetails> selectPlanBorrowDetailsList(PlanBorrowDetails planBorrowDetails);

    /**
     * 新增年度借调计划详细
     * 
     * @param planBorrowDetails 年度借调计划详细
     * @return 结果
     */
    public int insertPlanBorrowDetails(PlanBorrowDetails planBorrowDetails);

    /**
     * 修改年度借调计划详细
     * 
     * @param planBorrowDetails 年度借调计划详细
     * @return 结果
     */
    public int updatePlanBorrowDetails(PlanBorrowDetails planBorrowDetails);

    /**
     * 删除年度借调计划详细
     * 
     * @param planId 年度借调计划详细主键
     * @return 结果
     */
    public int deletePlanBorrowDetailsByPlanId(Long planId);

    /**
     * 批量删除年度借调计划详细
     * 
     * @param planIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePlanBorrowDetailsByPlanIds(Long[] planIds);
}
