package com.bonus.material.plan.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.plan.domain.PlanBorrowDetails;
import com.bonus.material.plan.service.IPlanBorrowDetailsService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 年度借调计划详细Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "年度借调计划详细接口")
@RestController
@RequestMapping("/plan_borrow_details")
public class PlanBorrowDetailsController extends BaseController {
    @Autowired
    private IPlanBorrowDetailsService planBorrowDetailsService;

    /**
     * 查询年度借调计划详细列表
     */
    @ApiOperation(value = "查询年度借调计划详细列表")
    @RequiresPermissions("plan:details:list")
    @GetMapping("/list")
    public TableDataInfo list(PlanBorrowDetails planBorrowDetails) {
        startPage();
        List<PlanBorrowDetails> list = planBorrowDetailsService.selectPlanBorrowDetailsList(planBorrowDetails);
        return getDataTable(list);
    }

    /**
     * 导出年度借调计划详细列表
     */
    @ApiOperation(value = "导出年度借调计划详细列表")
    @PreventRepeatSubmit
    @RequiresPermissions("plan:details:export")
    @SysLog(title = "年度借调计划详细", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出年度借调计划详细")
    @PostMapping("/export")
    public void export(HttpServletResponse response, PlanBorrowDetails planBorrowDetails) {
        List<PlanBorrowDetails> list = planBorrowDetailsService.selectPlanBorrowDetailsList(planBorrowDetails);
        ExcelUtil<PlanBorrowDetails> util = new ExcelUtil<PlanBorrowDetails>(PlanBorrowDetails.class);
        util.exportExcel(response, list, "年度借调计划详细数据");
    }

    /**
     * 获取年度借调计划详细详细信息
     */
    @ApiOperation(value = "获取年度借调计划详细详细信息")
    @RequiresPermissions("plan:details:query")
    @GetMapping(value = "/{planId}")
    public AjaxResult getInfo(@PathVariable("planId") Long planId) {
        return success(planBorrowDetailsService.selectPlanBorrowDetailsByPlanId(planId));
    }

    /**
     * 新增年度借调计划详细
     */
    @ApiOperation(value = "新增年度借调计划详细")
    @PreventRepeatSubmit
    @RequiresPermissions("plan:details:add")
    @SysLog(title = "年度借调计划详细", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增年度借调计划详细")
    @PostMapping
    public AjaxResult add(@RequestBody PlanBorrowDetails planBorrowDetails) {
        try {
            return toAjax(planBorrowDetailsService.insertPlanBorrowDetails(planBorrowDetails));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改年度借调计划详细
     */
    @ApiOperation(value = "修改年度借调计划详细")
    @PreventRepeatSubmit
    @RequiresPermissions("plan:details:edit")
    @SysLog(title = "年度借调计划详细", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改年度借调计划详细")
    @PutMapping
    public AjaxResult edit(@RequestBody PlanBorrowDetails planBorrowDetails) {
        try {
            return toAjax(planBorrowDetailsService.updatePlanBorrowDetails(planBorrowDetails));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除年度借调计划详细
     */
    @ApiOperation(value = "删除年度借调计划详细")
    @PreventRepeatSubmit
    @RequiresPermissions("plan:details:remove")
    @SysLog(title = "年度借调计划详细", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除年度借调计划详细")
	@DeleteMapping("/{planIds}")
    public AjaxResult remove(@PathVariable Long[] planIds) {
        return toAjax(planBorrowDetailsService.deletePlanBorrowDetailsByPlanIds(planIds));
    }
}
